==> fantacalciobazar_0.2.1.tar.gz: fantacalciobazar/giornata.php <==
<?php

################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("head.php");

include("controlla_pass.php");
if ($pass_admin_errata == "NO") {



if ($copia_file_voti and $posizione_file) {
if (is_file("$giornata/voti.txt")) {
echo "file gi esistente, non copiato.";
$copiare = "NO";
} # fine if (is_file("$giornata/voti.txt"))
$lock = fopen("adnin.lock","w+");
flock($lock,2);
$voti = @file($posizione_file);
if (!$voti) {
echo "<b>file non trovato.</b>";
$copiare = "NO";
} # fine if (!$voti)
if ($copiare != "NO") {
$num_voti = count($voti);
$filevoti = fopen("$giornata/voti.txt","w+");
flock($filevoti,2);
rewind($filevoti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
fwrite($filevoti,$voti[$num1]);
} # fine for $num1
flock($filevoti,3);
fclose($filevoti);
} # fine if ($copiare != "NO")
flock($lock,3);
fclose($lock);
} # fine if ($copia_file_voti and $posizione_file)


echo "<center><b>$giornata</b></center>";
$tab_formazioni = "<tr>";
$num_colonne = 0;
$punti = "";

$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

if ($num_colonne >= 3) {
$tab_formazioni .= "</tr><tr>";
$num_colonne = 0;
} # fine if ($num_colonne >= 3)
$num_colonne++;
$tab_formazioni .= "<td>Squadra di $giocatore<br><br>";
$formazione = @file("$giornata/formazione_$giocatore");
$num_linee_formazione = count($formazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
$tab_formazioni .= $formazione[$num2]."<br>";
} # fine for $num2
$tab_formazioni .= "</td>
";

next($pass);
} # fine for $num1
for ($num1 = $num_colonne ; $num1 < 3; $num1++) $tab_formazioni .= "<td>&nbsp;</td>";
$tab_formazioni .= "</tr>";

echo "<table align=\"center\" border=\"1\">$tab_formazioni</table>";

if (is_file("$giornata/punteggi.txt")) {
echo "<table><tr><td>Risultati_della_$giornata<br>";
$punteggi = file("$giornata/punteggi.txt");
$num_punteggi = count($punteggi);
for ($num1 = 0 ; $num1 < $num_punteggi ; $num1++) {
$dati_punteggio = explode(",", $punteggi[$num1]);
settype($dati_punteggio[1],"double");
echo $dati_punteggio[0].": ".$dati_punteggio[1]."<br>";
$punti[$dati_punteggio[0]] = $dati_punteggio[1];
} # fine for $num1
$num_giornata = ereg_replace("giornata","",$giornata);
for ($num1 = "01" ; $num1 < $num_giornata ; $num1++) {
$giornata_punti = "giornata$num1";
if (is_file("$giornata_punti/punteggi.txt")) {
$punteggi = file("$giornata_punti/punteggi.txt");
$num_punteggi = count($punteggi);
for ($num2 = 0 ; $num2 < $num_punteggi ; $num2++) {
$dati_punteggio = explode(",", $punteggi[$num2]);
settype($dati_punteggio[1],"double");
$punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
} # fine for $num2
} # fine if (is_dir($giornata))
} # fine for $num1
echo "</td><td>Classifica_alla_$giornata<br>";
$num_giocatori=count($pass);
reset($pass);
for ($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
echo $giocatore.": ".$punti[$giocatore]."<br>";
next($pass);
} # fine for $num1
echo "</td></tr></table>";
echo "<center>Giornata chiusa.</center><br>";
} # fine if (is_file("$giornata/punteggi.txt"))

else {
if (is_file("$giornata/voti.txt")) {
echo "<center><form method=\"post\" action=\"calcola_punti_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"calcola\" value=\"Calcola i punteggi\">
</form></center>";
} # fine if (is_file("$giornata/voti.txt"))

else {
if ($prima_parte_pos_file_voti or $num_giornata_file_voti == "SI") {
$posizione_file = $prima_parte_pos_file_voti;
if ($num_giornata_file_voti == "SI") {
$num_giornata = ereg_replace("giornata","",$giornata);
$num_giornata = $num_giornata + $diff_num_giornata_file;
if ($num_giornata_file_voti_doppio == "SI") {
if (strlen($num_giornata) == 1) $num_giornata = "0".$num_giornata;
} # fine if ($num_giornata_file_voti_doppio == "SI")
$posizione_file .= "$num_giornata".$seconda_parte_pos_file_voti;
} # fine if ($num_giornata_file_voti == "SI")
echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"copia_file_voti\" value=\"Copia i voti\">
 dal file <input type=\"text\" name=\"posizione_file\" value=\"$posizione_file\" size=\"65\">
</form>";
} # fine if ($prima_parte_pos_file_voti or...
else echo "<center>Copia il file voti.txt nella cartella $giornata.</center><br>";
} # fine else if (is_file("$giornata/voti.txt"))
} # fine else if (is_file("$giornata/punteggi.txt"))

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine if ($pass_admin_errata == "NO")

include("foot.php");
?>

==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/giornata.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_admin_errata == "NO") {



$num_giornata = substr($giornata,8);

if ($copia_file_voti and $posizione_file) {
if (is_file("dati/voti$num_giornata.txt")) {
echo "file gi esistente, non copiato.";
$copiare = "NO";
} # fine if (is_file("dati/voti$num_giornata.txt"))
$lock = fopen("dati/admin.lock","w+");
flock($lock,2);
$voti = @file($posizione_file);
if (!$voti) {
echo "<b>file non trovato.</b>";
$copiare = "NO";
} # fine if (!$voti)
if ($copiare != "NO") {
$num_voti = count($voti);
$filevoti = fopen("dati/voti$num_giornata.txt","w+");
flock($filevoti,2);
rewind($filevoti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
fwrite($filevoti,$voti[$num1]);
} # fine for $num1
flock($filevoti,3);
fclose($filevoti);
} # fine if ($copiare != "NO")
flock($lock,3);
fclose($lock);
} # fine if ($copia_file_voti and $posizione_file)


echo "<center><b>$giornata</b></center>";
$tab_formazioni = "<tr>";
$num_colonne = 0;
$punti = "";
$num2 = 0;
$leggendo_formazioni = "SI";
$leggendo_punteggi = "NO";
$punteggi_esistenti = "NO";

$file_giornata = file("dati/$giornata");
$num_linee_file_giornata = count($file_giornata);
for($num1 = 0 ; $num1 < $num_linee_file_giornata; $num1++) {
$linea = substr($file_giornata[$num1],0,-1);
if ($linea == "#@& fine formazioni #@&") $leggendo_formazioni = "NO";
if ($leggendo_formazioni == "SI") {
if ($linea == "#@& formazione #@&") $giocatore = "";
if ($giocatore) {
${$formazione}[$num2] = $file_giornata[$num1];
$num2++;
} # fine if ($giocatore)
if ($aggiorna_giocatore) {
$giocatore = $linea;
$formazione = "formazione_$giocatore";
$num2 = 0;
$aggiorna_giocatore = "";
} # fine if ($aggiorna_giocatore)
if ($linea == "#@& formazione #@&") $aggiorna_giocatore = "SI";
} # fine if ($leggendo_formazioni == "SI")
if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi[$num2] = $file_giornata[$num1];
$num2++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti = "SI";
$num2 = 0;
} # fine if ($leggendo_punteggi == "SI")
} # fine for $num1

$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

if ($num_colonne >= 3) {
$tab_formazioni .= "</tr><tr>";
$num_colonne = 0;
} # fine if ($num_colonne >= 3)
$num_colonne++;
$tab_formazioni .= "<td>Squadra di $giocatore<br><br>";
$formazione = "formazione_$giocatore";
$formazione = $$formazione;
$num_linee_formazione = count($formazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
$tab_formazioni .= $formazione[$num2]."<br>";
} # fine for $num2
$tab_formazioni .= "</td>
";

next($pass);
} # fine for $num1
for ($num1 = $num_colonne ; $num1 < 3; $num1++) $tab_formazioni .= "<td>&nbsp;</td>";
$tab_formazioni .= "</tr>";

echo "<table align=\"center\" border=\"1\">$tab_formazioni</table>";

if ($punteggi_esistenti == "SI") {
echo "<table><tr><td>Risultati_della_$giornata<br>";
$num_punteggi = count($punteggi);
for ($num1 = 0 ; $num1 < $num_punteggi ; $num1++) {
$dati_punteggio = explode(",", $punteggi[$num1]);
settype($dati_punteggio[1],"double");
echo $dati_punteggio[0].": ".$dati_punteggio[1]."<br>";
$punti[$dati_punteggio[0]] = $dati_punteggio[1];
} # fine for $num1

# calcolo la classifica fino a questa giornata
$num_giornata = ereg_replace("giornata","",$giornata);
for ($num1 = "01" ; $num1 < $num_giornata ; $num1++) {
if (strlen($num1) == 1) $num1 = "0".$num1;
$giornata_punti = "giornata$num1";
if (is_file("dati/$giornata_punti")) {
$file_giornata_p = @file("dati/$giornata_punti");
$num_linee_file_giornata_p = count($file_giornata_p);
$leggendo_punteggi = "NO";
$punteggi_esistenti_p = "NO";
for($num2 = 0 ; $num2 < $num_linee_file_giornata_p; $num2++) {
$linea = substr($file_giornata_p[$num2],0,-1);
if ($linea == "#@& fine punteggi #@&") $leggendo_punteggi = "NO";
if ($leggendo_punteggi == "SI") {
$punteggi_p[$num3] = $file_giornata_p[$num2];
$num3++;
} # fine if ($leggendo_punteggi == "SI")
if ($linea == "#@& punteggi #@&") {
$leggendo_punteggi = "SI";
$punteggi_esistenti_p = "SI";
$num3 = 0;
} # fine if ($leggendo_punteggi == "SI")
} # fine for $num1
if ($punteggi_esistenti_p == "SI") {
$num_punteggi_p = count($punteggi_p);
for ($num2 = 0 ; $num2 < $num_punteggi_p ; $num2++) {
$dati_punteggio = explode(",", $punteggi_p[$num2]);
settype($dati_punteggio[1],"double");
$punti[$dati_punteggio[0]] = ($punti[$dati_punteggio[0]] + $dati_punteggio[1]);
} # fine for $num2
} # fine if ($punteggi_esistenti_p == "SI")
} # fine if (is_file("dati/$giornata_punti"))
} # fine for $num1

echo "</td><td>Classifica_alla_$giornata<br>";
$num_giocatori=count($pass);
reset($pass);
for ($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
echo $giocatore.": ".$punti[$giocatore]."<br>";
next($pass);
} # fine for $num1
echo "</td></tr></table>";
echo "<center>Giornata chiusa.</center><br>";
} # fine if ($punteggi_esistenti == "SI")

else {
if (is_file("dati/voti$num_giornata.txt")) {
echo "<center><form method=\"post\" action=\"calcola_punti_giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"calcola\" value=\"Calcola i punteggi\">
</form></center>";
} # fine if (is_file("dati/voti$num_giornata.txt"))

else {
if ($prima_parte_pos_file_voti or $num_giornata_file_voti == "SI") {
$posizione_file = $prima_parte_pos_file_voti;
if ($num_giornata_file_voti == "SI") {
#$num_giornata = ereg_replace("giornata","",$giornata);
$num_giornata = $num_giornata + $diff_num_giornata_file;
if ($num_giornata_file_voti_doppio == "SI") {
if (strlen($num_giornata) == 1) $num_giornata = "0".$num_giornata;
} # fine if ($num_giornata_file_voti_doppio == "SI")
$posizione_file .= "$num_giornata".$seconda_parte_pos_file_voti;
} # fine if ($num_giornata_file_voti == "SI")
echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"copia_file_voti\" value=\"Copia i voti\">
 dal file <input type=\"text\" name=\"posizione_file\" value=\"$posizione_file\" size=\"65\">
</form>";
} # fine if ($prima_parte_pos_file_voti or...
else echo "<center>Copia il file voti$num_giornata.txt nella cartella dati.</center><br>";
} # fine else if (is_file("$giornata/voti.txt"))
} # fine else if (is_file("$giornata/punteggi.txt"))

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form></center>";

} # fine if ($pass_admin_errata == "NO")

include("dati/foot.php");
?>
